<?php

class plgAcymExample extends acymPlugin
{
    /**
     * This method is mandatory
     */
    public function __construct()
    {
        parent::__construct();
        // Set the $this->cms variable to the correct CMS ( Joomla or WordPress, don't forget the uppercase )
        $this->cms = 'WordPress';

        /*
        If this is an integration with a WP plugin or a Joomla extension, you should make sure the integrated extension is installed on the site to avoid any issue.
        If it's not the case, set $this->installed = false; to hide your plugin's interface

        For WordPress:

        if (!file_exists($this->pluginsPath.'woocommerce')) {
            $this->installed = false;
        }

        For Joomla:

        if (!defined('JPATH_ADMINISTRATOR') || !file_exists(rtrim(JPATH_ADMINISTRATOR, DS).DS.'components'.DS.'com_hikashop'.DS)) {
            $this->installed = false;
        }
        */

        // We usually declare the inserted shortcodes like this, but this is optional
        $this->name = 'example';
    }


    /* * * * * * * * *
     * Dynamic texts *
     * * * * * * * * */


    /**
     * This method is optional, it is used to declare a new dynamic text tab in the editor when editing a text
     */
    public function dynamicText()
    {
        $onePlugin = new stdClass();
        // Title displayed on the tab in the dtexts popup
        $onePlugin->name = 'Example';
        $onePlugin->plugin = __CLASS__;

        return $onePlugin;
    }

    /**
     * This method is mandatory if you declare a new dynamic text. It is used to display the options and interface of your dynamic text's tab, in the popup for dynamic text insertion
     */
    public function textPopup()
    {
        $text = '<div class="acym__popup__listing text-center grid-x">
                    <h1 class="acym__popup__plugin__title cell">This is only en example, you can display any option here:</h1>';

        $others = array();
        $others['{'.$this->name.':45|anoption}'] = 'Some description, like "Name"';
        $others['{'.$this->name.':7}'] = 'Some other description, like "Phone number"';


        foreach ($others as $tagname => $tag) {
            $text .= '<div class="grid-x medium-12 cell acym__listing__row acym__listing__row__popup text-left" onclick="setTag(\''.$tagname.'\', $(this));" >
                        <div class="cell small-12 acym__listing__title acym__listing__title__dynamics">'.$tag.'</div>
                     </div>';
        }

        $text .= '</div>';

        echo $text;
    }


    /* * * * * * * * * *
     * Dynamic content *
     * * * * * * * * * */


    /**
     * This method is optional and is used to declare a new dynamic content button that can be dragged in the editor
     */
    function insertOptions()
    {
        $plugins = new stdClass();
        // Text displayed on the button
        $plugins->name = 'Example';
        // This is optional, if you set it, a tooltip text will be shown when hovering the button
        $plugins->title = 'Insert example content';
        // Path to the icon displayed on the button. It can be a svg, png, gif, jpg, etc... file
        $plugins->icon = ACYM_DYNAMICS_URL.basename(__DIR__).'/icon.svg';
        $plugins->plugin = __CLASS__;

        return $plugins;
    }

    /**
     * This method is mandatory if you declared a dynamic content.
     * It is used to show the options needed to customize what you want to insert in the email.
     *
     * For a better example, download the WooCommerce or HikaShop plugins and take a look at the code
     */
    public function contentPopup()
    {
        /*
         * If needed, you can declare some options here
         */
        $displayOptions = array(
            array(
                'title' => 'ACYM_DISPLAY',
                'type' => 'checkbox', // checkbox, boolean, intextfield, pictures, radio, select, multiselect, text, number, date
                'name' => 'display',
                'options' => array(
                    'title' => array('ACYM_TITLE', true),
                    'price' => array('ACYM_PRICE', true),
                    'desc' => array('ACYM_DESCRIPTION', true),
                    'shortdesc' => array('ACYM_SHORT_DESCRIPTION', false),
                    'cats' => array('ACYM_CATEGORIES', false),
                    'attribs' => array('ACYM_DETAILS', false),
                ),
                'class' => 'a_CSS_class_for_this_option',
            ),
            array(
                'title' => 'ACYM_CLICKABLE_TITLE',
                'type' => 'boolean',
                'name' => 'clickable',
                'default' => true,
            ),
            array(
                'title' => 'Some text option',
                'type' => 'text',
                'name' => 'wrap',
                'default' => 0,
            ),
            array(
                'title' => 'ACYM_DISPLAY_PICTURES',
                'type' => 'pictures',
                'name' => 'pictures',
            ),
        );

        echo $this->acympluginHelper->displayOptions($displayOptions, $this->name);
        echo '<div id="plugin_listing" class="acym__popup__listing padding-0">';
        $this->displayListing();
        echo '</div>';
    }

    /**
     * You defined some options, good !
     * Now display a listing of the elements you propose to insert
     */
    private function displayListing()
    {
        /*
         * Build here the SQL query to get the elements you want to list
         * Keep the SQL_CALC_FOUND_ROWS, it is used for the pagination
         */
        $query = 'SELECT SQL_CALC_FOUND_ROWS ID, post_title FROM #__posts WHERE (post_status = "publish") ';



        echo '<input type="hidden" name="plugin" value="'.__CLASS__.'" />';

        $pageInfo = new stdClass();
        $pageInfo->limit = acym_getCMSConfig('list_limit');
        $pageInfo->page = acym_getVar('int', 'pagination_page_ajax', 1);
        $pageInfo->start = ($pageInfo->page - 1) * $pageInfo->limit;

        $rows = acym_loadObjectList($query, '', $pageInfo->start, $pageInfo->limit);
        $pageInfo->total = acym_loadResult('SELECT FOUND_ROWS()');

        $selected = explode(',', acym_getVar('string', 'selected', ''));

        // We display here the listing
        echo '<div class="cell grid-x hide-for-small-only plugin_listing_headers">
                <div class="cell medium-5">'.acym_translation('ACYM_TITLE').'</div>
                <div class="cell medium-1">'.acym_translation('ACYM_ID').'</div>
            </div>';


        if (empty($rows)) {
            echo '<h1 class="cell acym__listing__empty__search__modal text-center">'.acym_translation('ACYM_NO_RESULTS_FOUND').'</h1>';
        }else {
            foreach ($rows as $row) {
                $class = 'cell grid-x acym__listing__row acym__listing__row__popup';
                if (in_array($row->ID, $selected)) $class .= ' selected_row';

                echo '<div class="'.$class.'" data-id="'.$row->ID.'" onclick="applyContent'.$this->name.'('.$row->ID.', this);">
                    <div class="cell medium-5">'.$row->post_title.'</div>
                    <div class="cell medium-1">'.$row->ID.'</div>
                </div>';
            }
        }


        $pagination = acym_get('helper.pagination');
        $pagination->setStatus($pageInfo->total, $pageInfo->page, $pageInfo->limit);
        echo $pagination->displayAjax();
    }


    /* * * * * * * * * * *
     * Replace shortcode *
     * * * * * * * * * * */



    /**
     * This method is used to replace the "shortcodes" in the sent emails. {exampleidentifier:7} in this example
     *
     * $email => The email object, if you need to modify something in this object, make sure to do it right...
     * $send  => If this variable is true, the email will be sent, if it's false the email won't be sent (on the summary page for example)
     */
    public function replaceContent(&$email, $send = true)
    {
        // You can use this special function to get a formatted array with all the shortcodes included in your email
        $extractedTags = $this->acympluginHelper->extractTags($email, 'exampleidentifier');

        // If none of your shortcodes are found in the email, no need to go further
        if (empty($extractedTags)) return;

        $tags = array();
        foreach ($extractedTags as $shortcode => $oneTag) {
            if (isset($tags[$shortcode])) continue;

            $textDisplayed = '';

            /*
             For each shortcode you will have to return the content you want to display.
             If the shortcode {exampleidentifier:45|anoption|foo:bar} is found, $oneTag will be like this:

             object {
                 'id' => 45,
                 'anoption' => true,
                 'foo' => 'bar'
             }
             */

            if (!empty($oneTag->foo) && $oneTag->foo == 'bar') {
                $textDisplayed = 'Display this text';
            } else {
                $textDisplayed = 'Display this other text';
            }

            $tags[$shortcode] = $textDisplayed;
        }

        // This function will replace the shortcodes in the email
        $this->acympluginHelper->replaceTags($email, $tags);
    }

    /**
     * This method is almost the same as the previous one, except that it is called FOR EACH user the email is sent to
     * used to replace the "shortcodes" in the sent emails. {exampleidentifier:7} in this example
     *
     * $email => The email object, if you need to modify something in this object, make sure to do it right...
     * $user  => The user object, you can then access to its data if you want to customize what you display
     * $send  => If this variable is true, the email will be sent, if it's false the email won't be sent (on the summary page for example)
     */
    public function replaceUserInformation(&$email, &$user, $send = true)
    {
        $extractedTags = $this->acympluginHelper->extractTags($email, $this->name);
        if (empty($extractedTags)) return;


        if (empty($user->cms_id)) {
            // The current user hasn't any account created on the site (only an AcyMailing user)
        }

        $tags = array();
        foreach ($extractedTags as $i => $oneTag) {
            if (isset($tags[$i])) continue;

            $tags[$i] = 'Some content';
        }

        $this->acympluginHelper->replaceTags($email, $tags);
    }
}